@@ -1,12 +1,10 @@
-require 'fog/core/collection'
-require 'fog/brightbox/models/compute/database_server'
+require "fog/core/collection"
+require "fog/brightbox/models/compute/database_server"
 
 module Fog
   module Compute
     class Brightbox
-
       class DatabaseServers < Fog::Collection
-
         model Fog::Compute::Brightbox::DatabaseServer
 
         def all
@@ -20,9 +18,7 @@ module Fog
         rescue Excon::Errors::NotFound
           nil
         end
-
       end
-
     end
   end
 end
