@@ -1,9 +1,12 @@
-require 'fog/core/model'
+require "fog/brightbox/model"
+require "fog/brightbox/compute/resource_locking"
 
 module Fog
   module Compute
     class Brightbox
-      class DatabaseSnapshot < Fog::Model
+      class DatabaseSnapshot < Fog::Brightbox::Model
+        include Fog::Brightbox::Compute::ResourceLocking
+
         identity :id
         attribute :url
         attribute :resource_type
