@@ -1,9 +1,9 @@
-require 'fog/core/model'
+require "fog/brightbox/model"
 
 module Fog
   module Compute
     class Brightbox
-      class DatabaseType < Fog::Model
+      class DatabaseType < Fog::Brightbox::Model
         identity :id
         attribute :url
         attribute :resource_type
