@@ -1,12 +1,10 @@
-require 'fog/core/collection'
-require 'fog/brightbox/models/compute/database_type'
+require "fog/core/collection"
+require "fog/brightbox/models/compute/database_type"
 
 module Fog
   module Compute
     class Brightbox
-
       class DatabaseTypes < Fog::Collection
-
         model Fog::Compute::Brightbox::DatabaseType
 
         def all
