@@ -1,11 +1,9 @@
-require 'fog/core/model'
+require "fog/brightbox/model"
 
 module Fog
   module Compute
     class Brightbox
-
-      class Zone < Fog::Model
-
+      class Zone < Fog::Brightbox::Model
         identity :id
         attribute :url
         attribute :resource_type
@@ -14,9 +12,7 @@ module Fog
         attribute :handle
 
         attribute :description
-
       end
-
     end
   end
 end
